@@ -30,15 +30,37 @@ class Retry:
 
 
 class RunTime:
+    @classmethod
+    def run_time(cls, logger=print, show_short_result: int = None):
+        """
+        :param logger: logger func, default is python print
+        :param show_short_result: displays the result of the number of characters.
+        """
+        def decorator(func):
+            @functools.wraps(func)
+            def wrapper(*args, **kwargs):
+                start = time.time()
+                res = func(*args, **kwargs)
+                end = time.time()
+                logger(
+                    f'\n##########################################'
+                    f'\nSTART: {round(start, 2)} END: {round(end, 2)}'
+                    f'\nTOTAL TIME: {round(end - start, 2)}'
+                    f'\n##########################################'
+                    f'\nRESULT: '+(f'{res}'[:show_short_result]+'......' if show_short_result else f'{res}'))
+                return res
+            return wrapper
+        return decorator
 
     @classmethod
-    def loop_time(cls, loop_times: int = None, loop_sleep: int = 0, logger=print):
+    def loop_time(cls, loop_times: int = None, loop_sleep: int = 0, logger=print, show_short_result: int = None):
         def decorator(func):
             @functools.wraps(func)
             def wrapper(*args, **kwargs):
                 n, flag, start = 1, True, time.time()
-                (cls.__rangetime(loop_times, n, func, loop_sleep, logger, *args, **kwargs) if loop_times else
-                 cls.__whiletime(flag, n, func, loop_sleep, logger, *args, **kwargs))
+                (cls.__rangetime(loop_times, n, func, loop_sleep, logger, show_short_result, *args, **kwargs)
+                 if loop_times else
+                 cls.__whiletime(flag, n, func, loop_sleep, logger, show_short_result, *args, **kwargs))
                 end = time.time()
                 logger(
                     f'\n##########################################'
@@ -49,31 +71,14 @@ class RunTime:
         return decorator
 
     @classmethod
-    def run_time(cls, logger=print):
-        def decorator(func):
-            @functools.wraps(func)
-            def wrapper(*args, **kwargs):
-                start = time.time()
-                res = func(*args, **kwargs)
-                end = time.time()
-                logger(
-                    f'\n##########################################'
-                    f'\nSTART: {round(start, 2)} END: {round(end, 2)}'
-                    f'\nTOTAL TIME: {round(end - start, 2)}'
-                    f'\n##########################################'
-                    f'\nRESULT: {res}')
-                return res
-            return wrapper
-        return decorator
-
-    @classmethod
-    def __rangetime(cls, times, n, func, sleep, logger=print, *args, **kwargs):
+    def __rangetime(cls, times, n, func, sleep, logger=print, show_short_result: int = None, *args, **kwargs):
         res = True
         for _ in range(times):
             if res:
                 start = time.time()
                 res = func(*args, **kwargs)
-                logger(f'RESULT: {res or "Range loop: Nothing returned."}\n'
+                show_res = f'{res}'[:show_short_result]+'......' if show_short_result else f'{res}'
+                logger(f'RESULT: {show_res or "Range loop: Nothing returned."}\n'
                        f'Times: {n}, Time_cost: {time.time() - start}\n')
                 time.sleep(sleep)
                 n += 1
@@ -81,11 +86,12 @@ class RunTime:
                 break
 
     @classmethod
-    def __whiletime(cls, flag, n, func, sleep, logger=print, *args, **kwargs):
+    def __whiletime(cls, flag, n, func, sleep, logger=print, show_short_result: int = None, *args, **kwargs):
         while flag:
             start = time.time()
             res = func(*args, **kwargs)
-            logger(f'RESULT: {res or "While loop: Nothing returned."}\n'
+            show_res = f'{res}'[:show_short_result] + '......' if show_short_result else f'{res}'
+            logger(f'RESULT: {show_res or "While loop: Nothing returned."}\n'
                    f'Times: {n}, Time_cost: {time.time() - start}\n')
             time.sleep(sleep)
             n += 1
